Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(31)

Unified Diff: gm/rebaseline_server/static/loader.js

Issue 25045003: HTTP GM results viewer: server now returns category summaries along with testData (Closed) Base URL: http://skia.googlecode.com/svn/trunk/
Patch Set: final_tweaks Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gm/rebaseline_server/server.py ('k') | gm/rebaseline_server/static/view.html » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gm/rebaseline_server/static/loader.js
===================================================================
--- gm/rebaseline_server/static/loader.js (revision 11507)
+++ gm/rebaseline_server/static/loader.js (working copy)
@@ -1,7 +1,7 @@
/*
* Loader:
* Reads GM result reports written out by results_loader.py, and imports
* their data into $scope.results .
*/
var Loader = angular.module(
'Loader',
@@ -12,8 +12,10 @@
function($scope, $http) {
$http.get("/results/all").then(
function(response) {
- $scope.results = response.data;
+ $scope.categories = response.data.categories;
+ $scope.testData = response.data.testData;
$scope.sortColumn = 'test';
+ $scope.showResultsOfType = 'failed';
}
);
}
@@ -1,7 +1,7 @@
/*
* Loader:
- * Reads GM result reports written out by results_loader.py, and imports
- * their data into $scope.results .
+ * Reads GM result reports written out by results.py, and imports
+ * them into $scope.categories and $scope.testData .
*/
var Loader = angular.module(
« no previous file with comments | « gm/rebaseline_server/server.py ('k') | gm/rebaseline_server/static/view.html » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698